; Windows OS.jss
; (c) 2018 by Udo Egner-Walter

Include "HjGlobal.jsh"
Include "hjconst.jsh"
Include "common.jsm"
include "UIA.jsh"
include "Windows OS.jsh"
; FS-Datei mit einbinden 
use "Windows OS.jsb"

; -----------------------------------------------------------------------------------------------
; bersicht Funktionen
; -----------------------------------------------------------------------------------------------
; string Function GetEditValue (string sName) - den Wert von Eingabefeldern ermitteln 
; int Function IsCommonTabActive () - Prfen, ob die Registerkarte "Allgemein" vorhanden und aktiv ist 
; int Function IsCommonTabAvailable () - Prfen, ob die Registerkarte "Allgemein" vorhanden ist
; int Function GetDialogType () - Ermittelt den Dialog-Typ (Datei, Ordner oder Laufwerk)
; string Function GetSummary () - Statischen Text (Zusammenfassung der markierten Objekte)
; string Function GetDriveType () - Laufwerkstyp ermitteln
; String Function GetDriveName () - Laufwerksnamen ber Dialogtitel 
; String Function GetDriveLetter() - Laufwerksbuchstaben ber Dialogtitel 
; int Function IsPropertyDialog () - Prft, ob der Eigenschaften-Dialog aktiv ist 
; string function GetDriveSize () - Gibt die Kapazitt des Laufwerks zurck
; string function GetFileSystem () - Gibt das Dateisystem der Festplatte zurck
; string function GetDiscSpace () - Gibt den belegten Speicherplatz zurck
; string function GetDiscSpaceFree () - Gibt den freien Speicherplatz zurck
; -----------------------------------------------------------------------------------------------
; bersicht Skripts
; -----------------------------------------------------------------------------------------------
; Script SaySummary () - Spricht eine Zusammenfassung des Dialogs 
; Script SayName () - Spricht Datei-, Ordner- oder Laufwerksname 
; Script SayLocation () - Spricht Datei- und Ordnerspeicherort sowie Laufwerksbuchstaben
; Script SayType () - Spricht Datei-, Ordner- oder Laufwerkstyp
; Script SayProg () - Spricht mit welchem Programm die Datei verknpft ist 
; Script SaySize () - Spricht Datei-, Ordnergre Laufwerkskapazitt
; Script SaySizeOnDisc () - Spricht Datei-, Ordnergre auf der Festplatte bzw. Dateisystem bei Festplatten
; Script SayDiscspace () - Spricht belegter Speicherplatz
; Script SayDiscspaceFree () - Spricht freien Speicherplatz
; Script SayCreationDate () - ; Spricht Erstellungsdatum
; Script SayChangeDate () - Spricht nderungsdatum
; Script SayLastAccessDate () - Spricht letzten Dateizugriff
; Script SayAttributes () - Spricht Attribute 
; Script SayHelp () - Hilfe (Anzeigen im virtuellen Betrachter)
; -----------------------------------------------------------------------------------------------

; ooooooooooooooooooooooooooooooooooooooooooooooooo
; Funktionen
; ooooooooooooooooooooooooooooooooooooooooooooooooo

; --------------------------------------------------------------------------------------------
; Spicht Text und stellt ihn auf der Braillezeile dar
; --------------------------------------------------------------------------------------------

void Function SayStringAndSendToBraille (string sMessage)
SayFormattedMessage (OT_STATUS, sMessage)
If GetNonJCFOption("UseFlashMessageForWindowsOS") then
BrailleMessage (sMessage)
else
BrailleString (sMessage)
EndIf 
EndFunction

; --------------------------------------------------------------------------------------------
; Den Wert von Eingabefeldern ermitteln 
; --------------------------------------------------------------------------------------------

string Function GetEditValue (string sName)
var
object oUIA, 
object oElement, 
object oCondition, 
object oValuePattern, 
handle hDialog

hDialog = GetRealWindow(GetFocus())
oUIA = CreateObjectEx ("FreedomSci.UIA", 0, "UIAScriptAPI.x.manifest")
oElement = oUIA.GetElementFromHandle (hDialog)
If !oElement then Return EndIf 
oCondition = oUIA.CreateAndCondition(
oUIA.CreateIntPropertyCondition(UIA_ControlTypePropertyId, UIA_EditControlTypeId),
oUIA.CreateStringPropertyCondition (UIA_NamePropertyId, sName))
If !oCondition then Return EndIf 
oElement = oElement.FindFirst (TreeScope_Descendants, oCondition)
If !oElement then Return EndIf 
oValuePattern = oElement.GetValuePattern()
Return oValuePattern.Value
EndFunction 

; --------------------------------------------------------------------------------------------
; Prfen, ob die Registerkarte "Allgemein" vorhanden und 
; aktiv ist 
; --------------------------------------------------------------------------------------------

int Function IsCommonTabActive ()
var 
string sTitle = GetWindowName (GetRealWindow(GetFocus())),
object oUIA, 
object oElement, 
object oCondition, 
object oSelectionItemPattern, 
handle hDialog

hDialog = GetRealWindow(GetFocus())
oUIA = CreateObjectEx ("FreedomSci.UIA", 0, "UIAScriptAPI.x.manifest")
oElement = oUIA.GetElementFromHandle (hDialog)
If !oElement then Return EndIf 
oCondition = oUIA.CreateAndCondition(
oUIA.CreateIntPropertyCondition(UIA_ControlTypePropertyId, UIA_TabItemControlTypeId),
oUIA.CreateStringPropertyCondition (UIA_NamePropertyId, cTabControlCommon))
If !oCondition then Return EndIf 
oElement = oElement.FindFirst (TreeScope_Descendants, oCondition)
If !oElement then 
Return false 
else
oSelectionItemPattern = oElement.GetSelectionItemPattern()
     if oSelectionItemPattern.IsSelected then
     Return True
     else
     Return False
     EndIf ; if oSelectionItemPattern.IsSelected then
EndIf ; If !oElement then 
EndFunction

; --------------------------------------------------------------------------------------------
; Prfen, ob die Registerkarte "Allgemein" vorhanden ist
; --------------------------------------------------------------------------------------------

int Function IsCommonTabAvailable ()
var 
string sTitle = GetWindowName (GetRealWindow(GetFocus())),
object oUIA, 
object oElement, 
object oCondition, 
object oSelectionItemPattern, 
handle hDialog

hDialog = GetRealWindow(GetFocus())
oUIA = CreateObjectEx ("FreedomSci.UIA", 0, "UIAScriptAPI.x.manifest")
oElement = oUIA.GetElementFromHandle (hDialog)
If !oElement then Return EndIf 
oCondition = oUIA.CreateAndCondition(
oUIA.CreateIntPropertyCondition(UIA_ControlTypePropertyId, UIA_TabItemControlTypeId),
oUIA.CreateStringPropertyCondition (UIA_NamePropertyId, cTabControlCommon))
If !oCondition then Return EndIf 
oElement = oElement.FindFirst (TreeScope_Descendants, oCondition)
If !oElement then 
Return false 
else
Return True 
EndIf ; If !oElement then 
EndFunction

; --------------------------------------------------------------------------------------------
; Ermittelt den Dialog-Typ (Datei, Ordner oder Laufwerk)
; --------------------------------------------------------------------------------------------

int Function GetDialogType ()
var string sTitle = GetWindowName (GetRealWindow(GetFocus()))

If GetEditValue (cEditType) == cFolder then
Return IsFolder
EndIf ;If GetEditValue (cEditType) == cFolder then

If GetEditValue (cEditType) == cFolders then
Return AllFolders
EndIf ; If GetEditValue (cEditType) == cFolders then

If GetEditValue (cEditType) == cMultiType then
Return MixedTypes
EndIf ; If GetEditValue (cEditType) == cMultiType then

; Wenn im Fenstertitel ein Doppelpunkt vorkommt 
If StringContains (sTitle, cDialogTitle) && StringContains (sTitle, ":") then
; (dann handelt es sich um ein Laufwerk)
       ; wenn im Dialog die Registerkarte "Allgemein" vorkommt
      If IsCommonTabAvailable () then
       ; dann ist nur ein Laufwerk markiert
      Return IsDrive
      else
       ; andernfalls sind mehrere Laufwerke markiert 
      Return AllDrives
      EndIf ; If IsCommonTabAvailable () then
EndIf ; If StringContains (sTitle, cDialogTitle) && StringContains (sTitle, ":") then

If GetEditValue (cEditType) == "" then
Return IsFile
EndIf ; If GetEditValue (cEditType) == "" then

If StringContains (GetEditValue (cEditType), cSameType) then
Return AllFilesSameType
EndIf ; If StringContains (GetEditValue (cEditType), cSameType) then

EndFunction 

; --------------------------------------------------------------------------------------------
; Statischen Text (Zusammenfassung der markierten Objekte)
; --------------------------------------------------------------------------------------------

string Function GetSummary ()
var
object oUIA, 
object oElement, 
object oCondition, 
handle hDialog

hDialog = GetRealWindow(GetFocus())
oUIA = CreateObjectEx ("FreedomSci.UIA", 0, "UIAScriptAPI.x.manifest")
oElement = oUIA.GetElementFromHandle (hDialog)
If !oElement then Return EndIf 
oCondition = oUIA.CreateIntPropertyCondition(UIA_ControlTypePropertyId, UIA_TextControlTypeId)
If !oCondition then Return EndIf 
oElement = oElement.FindFirst (TreeScope_Descendants, oCondition)
If !oElement then Return EndIf 
Return oElement.Name
EndFunction 

; --------------------------------------------------------------------------------------------
; Laufwerkstyp ermitteln
; --------------------------------------------------------------------------------------------

string Function GetDriveType ()
var
object oUIA, 
object oElements, 
object oEntry, 
object oCondition, 
int i = -1,
handle hDialog

hDialog = GetRealWindow(GetFocus())
oUIA = CreateObjectEx ("FreedomSci.UIA", 0, "UIAScriptAPI.x.manifest")
oElements = oUIA.GetElementFromHandle (hDialog)
If !oElements then Return EndIf 
oCondition = oUIA.CreateIntPropertyCondition(UIA_ControlTypePropertyId, UIA_TextControlTypeId)

If !oCondition then Return EndIf 
oElements = oElements.FindAll (TreeScope_Descendants, oCondition)
If !oElements then Return EndIf 

forEach oEntry in oElements 
i = i + 1
If oEntry.Name == cEditType then
Return (oElements(i+1).Name)
EndIf ; If oEntry.Name == cEditType then
EndForEach
EndFunction

; --------------------------------------------------------------------------------------------
; Laufwerksnamen ber Dialogtitel 
; --------------------------------------------------------------------------------------------

String Function GetDriveName ()
var
string sTitle = GetWindowName (GetRealWindow(GetFocus()))
sTitle = StringReplaceSubstrings (sTitle, cDialogTitle, "")
Return sTitle
EndFunction

; --------------------------------------------------------------------------------------------
; Laufwerksbuchstaben ber Dialogtitel 
; --------------------------------------------------------------------------------------------

String Function GetDriveLetter()
var
string sTitle = GetWindowName (GetRealWindow(GetFocus()))
sTitle = StringReplaceSubstrings (sTitle, cDialogTitle, "")
; die Zeichen links vom Doppelpunkt extrahieren 
sTitle = StringSegment (sTitle, ":", 1)
; von rechts ein Zeichen extrahieren (= Buchstabe vor dem Doppelpunkt)
sTitle = StringRight (sTitle, 1)
Return sTitle
EndFunction

; --------------------------------------------------------------------------------------------
; Prft, ob der Eigenschaften-Dialog aktiv ist 
; --------------------------------------------------------------------------------------------

int Function IsPropertyDialog ()
var string sTitle = GetWindowName (GetRealWindow(GetFocus()))
If StringContains(sTitle, cDialogTitle) then
Return True
else
Return False
EndIf ; If StringContains(sTitle, cDialogTitle) then
EndFunction

; --------------------------------------------------------------------------------------------
; Gibt die Kapazitt des Laufwerks zurck
; --------------------------------------------------------------------------------------------

string function GetDriveSize ()
var
object oUIA, 
object oElements, 
object oEntry, 
object oCondition,
int i = -1,
string sTemp, 
string sResult,
handle hDialog

hDialog = GetRealWindow(GetFocus())
oUIA = CreateObjectEx ("FreedomSci.UIA", 0, "UIAScriptAPI.x.manifest")
oElements = oUIA.GetElementFromHandle (hDialog)
If !oElements then Return EndIf 
oCondition = oUIA.CreateIntPropertyCondition(UIA_ControlTypePropertyId, UIA_TextControlTypeId)
If !oCondition then Return EndIf 
oElements = oElements.FindAll (TreeScope_Descendants, oCondition)
If !oElements then Return EndIf 

ForEach oEntry in oElements
i = i + 1
; Wenn wir beim Text "Speicherkapazitt:" sind, dann 
If oEntry.Name == cDiscSpace then
; enthlt das bernchste Text-Element die Speicherkapazitt (GB oder TB)
sTemp = oElements(i+2).Name 
sResult = sTemp
; und das nchste Text-Element die genaue Byte-Anzahl
sTemp = oElements(i+1).Name
sResult = sResult + ", " + sTemp
EndIf ; If oEntry.Name == cDiscSpace then
EndForEach
Return sResult
EndFunction

; --------------------------------------------------------------------------------------------
; Gibt das Dateisystem der Festplatte zurck
; --------------------------------------------------------------------------------------------

string function GetFileSystem ()
var
object oUIA, 
object oElements, 
object oEntry, 
object oCondition,
int i = -1,
handle hDialog

hDialog = GetRealWindow(GetFocus())
oUIA = CreateObjectEx ("FreedomSci.UIA", 0, "UIAScriptAPI.x.manifest")
oElements = oUIA.GetElementFromHandle (hDialog)
If !oElements then Return EndIf 
oCondition = oUIA.CreateIntPropertyCondition(UIA_ControlTypePropertyId, UIA_TextControlTypeId)
If !oCondition then Return EndIf 
oElements = oElements.FindAll (TreeScope_Descendants, oCondition)
If !oElements then Return EndIf 

ForEach oEntry in oElements
i = i + 1
; wenn das aktuelle Text-Element "Dateisystem:" ist, dann 
If oEntry.Name == cFilesystem then
; enthlt das folgende Text-Element den gesuchte Text
Return oElements(i+1).Name
EndIf ; If oEntry.Name == cFilesystem then
EndForEach
EndFunction

; --------------------------------------------------------------------------------------------
; Gibt den belegten Speicherplatz zurck
; --------------------------------------------------------------------------------------------

string function GetDiscSpace ()
var
object oUIA, 
object oElements, 
object oEntry, 
object oCondition,
string sTemp, 
string sResult,
int i = -1,
handle hDialog

hDialog = GetRealWindow(GetFocus())
oUIA = CreateObjectEx ("FreedomSci.UIA", 0, "UIAScriptAPI.x.manifest")
oElements = oUIA.GetElementFromHandle (hDialog)
If !oElements then Return EndIf 
oCondition = oUIA.CreateIntPropertyCondition(UIA_ControlTypePropertyId, UIA_TextControlTypeId)
If !oCondition then Return EndIf 
oElements = oElements.FindAll (TreeScope_Descendants, oCondition)
If !oElements then Return EndIf 
ForEach oEntry in oElements
i = i + 1
; wenn das aktuelle Text-Element "Belegter Speicher:" ist, dann 
If oEntry.Name == cSpace then
; ist das bernchste Text-Element der belegte Speicher (in GB oder TB)
sTemp = oElements(i+2).Name 
sResult = sTemp
; und das nchste Text-Element der belegte Speicher in Bytes
sTemp = oElements(i+1).Name
sResult = sResult + ", " + sTemp
EndIf ; If oEntry.Name == cSpace then
EndForEach
Return sResult
EndFunction

; --------------------------------------------------------------------------------------------
; Gibt den freien Speicherplatz zurck
; --------------------------------------------------------------------------------------------

string function GetDiscSpaceFree ()
var
object oUIA, 
object oElements, 
object oEntry, 
object oCondition,
string sTemp, 
string sResult,
int i = -1,
handle hDialog

hDialog = GetRealWindow(GetFocus())
oUIA = CreateObjectEx ("FreedomSci.UIA", 0, "UIAScriptAPI.x.manifest")
oElements = oUIA.GetElementFromHandle (hDialog)
If !oElements then Return EndIf 
oCondition = oUIA.CreateIntPropertyCondition(UIA_ControlTypePropertyId, UIA_TextControlTypeId)
If !oCondition then Return EndIf 
oElements = oElements.FindAll (TreeScope_Descendants, oCondition)
If !oElements then Return EndIf 

ForEach oEntry in oElements
i = i + 1
; Wenn das aktuelle Text-Element "Freier Speicher:" ist, dann 
If oEntry.Name == cFreeSpace then
; dann ist das bernchste Text-Eelment der freie Speicher (in GB oder TB)
sTemp = oElements(i+2).Name 
sResult = sTemp
; und das nchste Text-Element der freie Speicher in Bytes
sTemp = oElements(i+1).Name
sResult = sResult + ", " + sTemp
EndIf ; If oEntry.Name == cFreeSpace then
EndForEach
Return sResult
EndFunction

; ooooooooooooooooooooooooooooooooooooooooooooooooo
; Skripts
; ooooooooooooooooooooooooooooooooooooooooooooooooo

; --------------------------------------------------------------------------------------------
; Spricht eine Zusammenfassung des Dialogs 
; Standardtaste: Shift+Space&i&i
; --------------------------------------------------------------------------------------------

Script SaySummary ()
If !IsPropertyDialog () then Return EndIf 
If !IsCommonTabActive () then
SayStringAndSendToBraille (msgWrongTab)
Return
EndIf 

If GetDialogType () == AllFolders then 
SayStringAndSendToBraille (msgAllFolders)
SayStringAndSendToBraille (GetSummary ())
EndIf 

If GetDialogType () == IsFolder then 
SayStringAndSendToBraille (msgIsFolder)
EndIf 

If GetDialogType () == AllDrives then 
SayStringAndSendToBraille (msgAllDrives)
EndIf 

If GetDialogType () == IsDrive then 
SayStringAndSendToBraille (msgIsDrive)
EndIf 

If GetDialogType () == MixedTypes then 
SayStringAndSendToBraille (msgMixedTypes)
SayStringAndSendToBraille (GetSummary ())
EndIf 

If GetDialogType () == IsFile then 
SayStringAndSendToBraille (msgIsFile)
EndIf 

If GetDialogType () == AllFilesSameType then
SayStringAndSendToBraille (msgAllFilesSameType)
SayStringAndSendToBraille (GetSummary ())
EndIf 

SayStringAndSendToBraille (msgSayCheckboxAndState)
PerformScript SayAttributes ()
EndScript

; --------------------------------------------------------------------------------------------
; Spricht Datei-, Ordner- oder Laufwerksname 
; Standardtaste: Shift+Space&i&n
; --------------------------------------------------------------------------------------------

Script SayName ()
giCopyToClipboard = GetNonJCFOption("CopyToClipboardWindowsOS") 

If !IsPropertyDialog () then Return EndIf 
If !IsCommonTabActive () then
SayStringAndSendToBraille (msgWrongTab)
Return
EndIf 

If GetDialogType () == IsFolder then 
SayStringAndSendToBraille (FormatString (msgIsFolder_Name, GetEditValue  (cEditFolderName)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditFolderName))
      EndIf ; If giCopyToClipboard then
EndIf ;If GetDialogType () == IsFolder then 

If GetDialogType () == IsFile then 
SayStringAndSendToBraille (FormatString (msgIsFile_Name, GetEditValue  (cEditFileName)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditFileName))
      EndIf ; If giCopyToClipboard then
EndIf ; If GetDialogType () == IsFile then 
 
If GetDialogType () == IsDrive then 
SayStringAndSendToBraille (FormatString (msgIsDrive_Name, GetDriveName  ()))
      If giCopyToClipboard then
      CopyToClipboard (GetDriveName ())
      EndIf ; If giCopyToClipboard then
EndIf ; If GetDialogType () == IsDrive then 

If (GetDialogType () == AllFolders) then
SayStringAndSendToBraille (msgAllFolders_Name)
EndIf ; If (GetDialogType () == AllFolders) then

If (GetDialogType () == AllFiles) then 
SayStringAndSendToBraille (msgAllFiles_Name)
EndIf ; If (GetDialogType () == AllFiles) then 

If (GetDialogType () == AllDrives) then
SayStringAndSendToBraille (msgAllDrives_Name)
EndIf ; If (GetDialogType () == AllDrives) then

If (GetDialogType () == AllFilesSameType) then
SayStringAndSendToBraille (msgAllFilesSameType_Name)
EndIf ; If (GetDialogType () == AllFilesSameType) then

If (GetDialogType () == MixedTypes) then 
SayStringAndSendToBraille (msgMixedTypes_Name)
EndIf ; If (GetDialogType () == MixedTypes) then 

EndScript 

; ----------------------------------------------------------------------------------------------------
; Spricht Datei- und Ordnerspeicherort sowie Laufwerksbuchstaben
; -----------------------------------------------------------------------------------------------------

Script SayLocation ()
giCopyToClipboard = GetNonJCFOption("CopyToClipboardWindowsOS") 

If !IsPropertyDialog () then Return EndIf 
If !IsCommonTabActive () then
SayStringAndSendToBraille (msgWrongTab)
Return
EndIf 

If (GetDialogType () == IsFolder)
|| (GetDialogType () == IsFile)
|| (GetDialogType () == AllFolders)
|| (GetDialogType () == AllFiles)
|| (GetDialogType () == AllFilesSameType)
|| (GetDialogType () == MixedTypes)
then 
SayStringAndSendToBraille (FormatString (msgSayLocation, GetEditValue  (cEditLocationName)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditLocationName))
      EndIf ; If giCopyToClipboard then
EndIf ; If GetDialogType () == IsFolder then 

If GetDialogType () == IsDrive then 
SayStringAndSendToBraille (FormatString (msgSayDriveLetter, GetDriveLetter ()))
      If giCopyToClipboard then
      CopyToClipboard (GetDriveLetter ())
      EndIf ; If giCopyToClipboard then
EndIf ; If GetDialogType () == IsDrive then 

If (GetDialogType () == AllDrives) then
SayStringAndSendToBraille (msgSayNoDriveLetter)
EndIf ; If (GetDialogType () == AllDrives) then

EndScript 

; --------------------------------------------------------------------------------------------
; Spricht Datei-, Ordner- oder Laufwerkstyp
; --------------------------------------------------------------------------------------------

Script SayType ()
giCopyToClipboard = GetNonJCFOption("CopyToClipboardWindowsOS") 

If !IsPropertyDialog () then Return EndIf 
If !IsCommonTabActive () then
SayStringAndSendToBraille (msgWrongTab)
Return
EndIf 

If (GetDialogType () == IsFolder) 
|| (GetDialogType () == AllFolders)
|| (GetDialogType () == AllFilesSameType)
then 
SayStringAndSendToBraille (FormatString (msgSayType, GetEditValue  (cEditType)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditType))
      EndIf ; If giCopyToClipboard then
EndIf ;If GetDialogType () == IsFolder then 

If (GetDialogType () == IsFile) then 
SayStringAndSendToBraille (FormatString (msgSayFileType, GetEditValue  (cEditFileType)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditFileType))
      EndIf ; If giCopyToClipboard then
EndIf ; If GetDialogType () == IsFile then 
 
If GetDialogType () == IsDrive then 
SayStringAndSendToBraille (FormatString (msgSayDriveType, GetDriveType ()))
      If giCopyToClipboard then
      CopyToClipboard (GetDriveType ())
      EndIf ; If giCopyToClipboard then
EndIf ; If GetDialogType () == IsDrive then 

If (GetDialogType () == AllDrives) then
SayStringAndSendToBraille (msgSayNoDriveType)
EndIf ; If (GetDialogType () == AllDrives) then

If (GetDialogType () == MixedTypes) then 
SayStringAndSendToBraille (msgSayNoType)
EndIf ; If (GetDialogType () == MixedTypes) then 

EndScript 

; --------------------------------------------------------------------------------------------
; Spricht mit welchem Programm die Datei verknpft ist 
; --------------------------------------------------------------------------------------------

Script SayProg ()
giCopyToClipboard = GetNonJCFOption("CopyToClipboardWindowsOS") 

If !IsPropertyDialog () then Return EndIf 
If !IsCommonTabActive () then
SayStringAndSendToBraille (msgWrongTab)
Return
EndIf 

If (GetDialogType () == IsFolder) 
|| (GetDialogType () == IsDrive)
|| (GetDialogType () == AllDrives)
|| (GetDialogType () == AllFolders) 
|| (GetDialogType () == AllFiles)
|| (GetDialogType () == AllFilesSameType) 
|| (GetDialogType () == MixedTypes) 
then 
SayStringAndSendToBraille (msgSayNoProg)
EndIf ;If GetDialogType () == IsFolder then 

If GetDialogType () == IsFile then 
SayStringAndSendToBraille (FormatString (msgSayProg, GetEditValue  (cEditOpenWithProg)))
EndIf ; If GetDialogType () == IsFile then 

EndScript 

; --------------------------------------------------------------------------------------------
; Spricht Datei-, Ordnergre Laufwerkskapazitt
; --------------------------------------------------------------------------------------------

Script SaySize ()
giCopyToClipboard = GetNonJCFOption("CopyToClipboardWindowsOS") 

If !IsPropertyDialog () then Return EndIf 
If !IsCommonTabActive () then
SayStringAndSendToBraille (msgWrongTab)
Return
EndIf 

If GetDialogType () == IsFolder then 
SayStringAndSendToBraille (FormatString (msgSayIsFolder_Size, GetEditValue  (cEditSize)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditSize))
      EndIf ; If giCopyToClipboard then
EndIf ;If GetDialogType () == IsFolder then 

If GetDialogType () == IsFile then 
SayStringAndSendToBraille (FormatString (msgSayIsFile_Size, GetEditValue  (cEditSize)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditSize))
      EndIf ; If giCopyToClipboard then
EndIf ; If GetDialogType () == IsFile then 
 
If GetDialogType () == IsDrive then 
SayStringAndSendToBraille (FormatString (msgSayIsDrive_Size, GetDriveSize ()))
      If giCopyToClipboard then
      CopyToClipboard (GetDriveSize ())
      EndIf ; If giCopyToClipboard then
EndIf ; If GetDialogType () == IsDrive then 

If (GetDialogType () == AllFolders) then
SayStringAndSendToBraille (FormatString (msgSayAllFolders_Size, GetEditValue  (cEditSize)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditSize))
      EndIf ; If giCopyToClipboard then
EndIf ; If (GetDialogType () == AllFolders) then

If (GetDialogType () == AllFiles) 
|| (GetDialogType () == AllFilesSameType)
then 
SayStringAndSendToBraille (FormatString (msgSayAllFiles_Size, GetEditValue  (cEditSize)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditSize))
      EndIf ; If giCopyToClipboard then
EndIf ; If (GetDialogType () == AllFiles) then 

If (GetDialogType () == AllDrives) then
SayStringAndSendToBraille (msgSayNoAllDrives_Size)
EndIf ; If (GetDialogType () == AllDrives) then

If (GetDialogType () == MixedTypes) then 
SayStringAndSendToBraille (FormatString (msgSayMixedTypes_Size, GetEditValue  (cEditSize)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditSize))
      EndIf ; If giCopyToClipboard then
EndIf ; If (GetDialogType () == MixedTypes) then 

EndScript 

; --------------------------------------------------------------------------------------------
; Spricht Datei-, Ordnergre auf der Festplatte
; bzw. Dateisystem bei Festplatten
; --------------------------------------------------------------------------------------------

Script SaySizeOnDisc ()
giCopyToClipboard = GetNonJCFOption("CopyToClipboardWindowsOS") 

If !IsPropertyDialog () then Return EndIf 
If !IsCommonTabActive () then
SayStringAndSendToBraille (msgWrongTab)
Return
EndIf 

If GetDialogType () == IsFolder then 
SayStringAndSendToBraille (FormatString (msgSayIsFolder_SizeOnDisc, GetEditValue  (cEditSizeOnDisk)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditSizeOnDisk))
      EndIf ; If giCopyToClipboard then
EndIf ;If GetDialogType () == IsFolder then 

If GetDialogType () == IsFile then 
SayStringAndSendToBraille (FormatString (msgSayIsFile_SizeOnDisc, GetEditValue  (cEditSizeOnDisk)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditSizeOnDisk))
      EndIf ; If giCopyToClipboard then
EndIf ; If GetDialogType () == IsFile then 

If GetDialogType () == IsDrive then 
SayStringAndSendToBraille (FormatString (msgSayIsDrive_FileSystem, GetFileSystem ()))
      If giCopyToClipboard then
      CopyToClipboard (GetFileSystem ())
      EndIf ; If giCopyToClipboard then
EndIf ; If GetDialogType () == IsDrive then 

If (GetDialogType () == AllFolders) then
SayStringAndSendToBraille (FormatString (msgSayAllFolders_SizeOnDisc, GetEditValue  (cEditSizeOnDisk)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditSizeOnDisk))
      EndIf ; If giCopyToClipboard then
EndIf ; If (GetDialogType () == AllFolders) then

If (GetDialogType () == AllFiles) 
|| (GetDialogType () == AllFilesSameType)
then 
SayStringAndSendToBraille (FormatString (msgSayAllFiles_SizeOnDisc, GetEditValue  (cEditSizeOnDisk)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditSizeOnDisk))
      EndIf ; If giCopyToClipboard then
EndIf ; If (GetDialogType () == AllFiles) then 

If (GetDialogType () == AllDrives) then
SayStringAndSendToBraille (msgSayAllDrives_NoFileSystem)
EndIf ; If (GetDialogType () == AllDrives) then

If (GetDialogType () == MixedTypes) then 
SayStringAndSendToBraille (FormatString (msgSayMixedTypes_SizeOnDisc, GetEditValue  (cEditSizeOnDisk)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditSizeOnDisk))
      EndIf ; If giCopyToClipboard then
EndIf ; If (GetDialogType () == MixedTypes) then 

EndScript 

; --------------------------------------------------------------------------------------------
; Spricht belegter Speicherplatz
; --------------------------------------------------------------------------------------------

Script SayDiscspace ()
giCopyToClipboard = GetNonJCFOption("CopyToClipboardWindowsOS") 

If !IsPropertyDialog () then Return EndIf 
If !IsCommonTabActive () then
SayStringAndSendToBraille (msgWrongTab)
Return
EndIf 

If (GetDialogType () == IsDrive) then
SayStringAndSendToBraille (FormatString (msgSayDiscSpace, GetDiscspace()))
      If giCopyToClipboard then
      CopyToClipboard (GetDiscspace())
      EndIf ; If giCopyToClipboard then
Return
EndIf ; If (GetDialogType () == IsDrive) then

SayStringAndSendToBraille (msgSayNoDiscSpace)
EndScript 

; --------------------------------------------------------------------------------------------
; Spricht freien Speicherplatz
; --------------------------------------------------------------------------------------------

Script SayDiscspaceFree ()
giCopyToClipboard = GetNonJCFOption("CopyToClipboardWindowsOS") 

If !IsPropertyDialog () then Return EndIf 
If !IsCommonTabActive () then
SayStringAndSendToBraille (msgWrongTab)
Return
EndIf 

If (GetDialogType () == IsDrive) then
SayStringAndSendToBraille (FormatString (msgSayFreeDiscSpace, GetDiscspaceFree ()))
      If giCopyToClipboard then
      CopyToClipboard (GetDiscspaceFree ())
      EndIf ; If giCopyToClipboard then
Return
EndIf ; If (GetDialogType () == IsDrive) then

SayStringAndSendToBraille (msgSayNoFreeDiscSpace)
EndScript 

; --------------------------------------------------------------------------------------------
; Erstellungsdatum
; --------------------------------------------------------------------------------------------

Script SayCreationDate ()
giCopyToClipboard = GetNonJCFOption("CopyToClipboardWindowsOS") 

If !IsPropertyDialog () then Return EndIf 
If !IsCommonTabActive () then
SayStringAndSendToBraille (msgWrongTab)
Return
EndIf 

If GetDialogType () == IsFolder then 
SayStringAndSendToBraille (FormatString (msgSayIsFolder_CreationDate, GetEditValue  (cEditCreationDate)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditCreationDate))
      EndIf ; If giCopyToClipboard then
EndIf ;If GetDialogType () == IsFolder then 

If GetDialogType () == IsFile then 
SayStringAndSendToBraille (FormatString (msgSayIsFile_CreationDate, GetEditValue  (cEditCreationDate)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditCreationDate))
      EndIf ; If giCopyToClipboard then
EndIf ; If GetDialogType () == IsFile then 

If (GetDialogType () == IsDrive)
|| (GetDialogType () == AllFolders) 
|| (GetDialogType () == AllFiles) 
|| (GetDialogType () == AllDrives)
|| (GetDialogType () == AllFilesSameType)
|| (GetDialogType () == MixedTypes) 
then 
SayStringAndSendToBraille (msgSayNoCreationDate)
EndIf ; If GetDialogType () == IsDrive then 
EndScript 

; --------------------------------------------------------------------------------------------
; nderungsdatum
; --------------------------------------------------------------------------------------------

Script SayChangeDate ()
giCopyToClipboard = GetNonJCFOption("CopyToClipboardWindowsOS") 

If !IsPropertyDialog () then Return EndIf 
If !IsCommonTabActive () then
SayStringAndSendToBraille (msgWrongTab)
Return
EndIf 

If GetDialogType () == IsFile then 
SayStringAndSendToBraille (FormatString (msgSayIsFile_ChangeDate, GetEditValue  (cEditChangeDate)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditChangeDate))
      EndIf ; If giCopyToClipboard then
EndIf ; If GetDialogType () == IsFile then 

If (GetDialogType () == IsDrive)
|| (GetDialogType () == AllFolders) 
|| (GetDialogType () == AllFiles) 
|| (GetDialogType () == AllDrives)
|| (GetDialogType () == AllFilesSameType)
|| (GetDialogType () == MixedTypes) 
|| (GetDialogType () == IsFolder)
then 
SayStringAndSendToBraille (msgSayNoChangeDate)
EndIf ; If GetDialogType () == IsDrive then 
EndScript 

; --------------------------------------------------------------------------------------------
; Spricht letzten Dateizugriff
; --------------------------------------------------------------------------------------------

Script SayLastAccessDate ()
giCopyToClipboard = GetNonJCFOption("CopyToClipboardWindowsOS") 

If !IsPropertyDialog () then Return EndIf 
If !IsCommonTabActive () then
SayStringAndSendToBraille (msgWrongTab)
Return
EndIf 

If GetDialogType () == IsFile then 
SayStringAndSendToBraille (FormatString (msgSayIsFile_LastAccessDate, GetEditValue  (cEditLastAccessDate)))
      If giCopyToClipboard then
      CopyToClipboard (GetEditValue  (cEditLastAccessDate))
      EndIf ; If giCopyToClipboard then
EndIf ; If GetDialogType () == IsFile then 
 
If (GetDialogType () == IsDrive)
|| (GetDialogType () == AllFolders) 
|| (GetDialogType () == IsFolder)
|| (GetDialogType () == AllFiles) 
|| (GetDialogType () == AllDrives)
|| (GetDialogType () == AllFilesSameType)
|| (GetDialogType () == MixedTypes) 
then 
SayStringAndSendToBraille (msgSayNoLastAccessDate)
EndIf ; If GetDialogType () == IsDrive then 
EndScript 

; --------------------------------------------------------------------------------------------
; Spricht Attribute 
; - Schreibgeschtzt und Versteckt bei Ordner
; - Schreibgeschtzt und Versteckt bei Dateien
; - Laufwerk komprimieren und Indizierung bei Laufwerken
; --------------------------------------------------------------------------------------------

Script SayAttributes ()
giCopyToClipboard = GetNonJCFOption("CopyToClipboardWindowsOS") 

If !IsPropertyDialog () then Return EndIf 
If !IsCommonTabActive () then
SayStringAndSendToBraille (msgWrongTab)
Return
EndIf 

var
object oUIA, 
object oElements, 
object oEntry, 
object oCondition, 
object oTogglePattern,
handle hDialog

hDialog = GetRealWindow(GetFocus())
oUIA = CreateObjectEx ("FreedomSci.UIA", 0, "UIAScriptAPI.x.manifest")
oElements = oUIA.GetElementFromHandle (hDialog)
If !oElements then Return EndIf 
oCondition = oUIA.CreateIntPropertyCondition(UIA_ControlTypePropertyId, UIA_CheckBoxControlTypeId)

If !oCondition then Return EndIf 
oElements = oElements.FindAll (TreeScope_Descendants, oCondition)
If !oElements then Return EndIf 

ForEach oEntry in oElements
SayStringAndSendToBraille (oEntry.Name)
oTogglePattern = oEntry.getTogglePattern()
If oTogglePattern.ToggleState == 0 then
SayStringAndSendToBraille (msgNotChecked)
elIf oTogglePattern.ToggleState == 1 then
SayStringAndSendToBraille (msgChecked)
elIf oTogglePattern.ToggleState == 2 then
SayStringAndSendToBraille (msgPartlyChecked)
EndIf ; If oTogglePattern.ToggleState == 0 then
EndForEach

EndScript 

; --------------------------------------------------------------------------------------------
; Hilfe (Anzeigen im virtuellen Betrachter)
; --------------------------------------------------------------------------------------------

Script SayHelp ()

; Sicherstellen, dass kein virtueller Betrachter geffnet ist 
EnsureNoUserBufferActive ()
UserBufferAddText ("Tastenkombinationen fr den Eigenschaften-Dialog:")
UserBufferAddText (" ")
UserBufferAddText ("Vorbemerkung:")
UserBufferAddText ("Alle folgenden Befehle werden eingeleitet mit der Tastenkombination: Umschalt+Leertaste+i")
UserBufferAddText (" ")
UserBufferAddText ("Drcken Sie im Anschluss eine der Folgenden Tasten, um weitere Infos zu erhalten: ")
UserBufferAddText ("z: (Zusammenfassung) - spricht eine Zusammenfassung des Dialogs")
UserBufferAddText ("n: (Namen) - spricht Ordner- bzw. Dateinamen oder Laufwerksbezeichnung")
UserBufferAddText ("o: (Ort) - spricht den Pfad zu Ordner und Dateien bzw. den Laufwerksbuchstaben bei Laufwerken")
UserBufferAddText ("t: (Typ) - spricht den Dateityp, Laufwerkstyp bzw. ob es sich um einen Ordner handelt")
UserBufferAddText ("p: (Programm) - spricht bei Dateien, mit welchem Programm die Datei verknpft ist")
UserBufferAddText ("g: (Gre) - spricht die Gre des Ordners, der Datei bzw. die Speicherkapazitt bei Laufwerken")
UserBufferAddText ("d: (Datentrger) - spricht den belegten Speicher auf der Festplatte fr Ordner und Dateien bzw. das verwendete Dateisystem bei Laufwerken")
UserBufferAddText ("b: (belegter Speicher) - spricht den belegten Speicher bei Festplatten")
UserBufferAddText ("f: (freier Speicher) - spricht den freien Speicherplatz bei Festplatten")
UserBufferAddText ("e: (Erstellungsdatum) - spricht das Erstellungsdatum eines Ordners oder einer Datei")
UserBufferAddText ("v: (verndert) - spricht das nderungsdatum einer Datei")
UserBufferAddText ("l: (letzter Zugriff) - spricht das letzte Zugriffsdatum einer Datei")
UserBufferAddText ("a: (Attribute) - spricht alle Kontrollfelder mit deren Status")
UserBufferAddText ("h: (Hilfe) - Anzeigen der Hilfe im virtuellen Betrachter")

; Virtueller Betrachter anzeigen 
UserBufferActivate ()
SayAll ()
EndScript

